==> xmlsec-2.0.2-sources.jar: org/apache/xml/security/stax/impl/stax/XMLSecEntityReferenceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.xml.security.stax.impl.stax;

import org.apache.xml.security.stax.ext.stax.XMLSecEntityReference;
import org.apache.xml.security.stax.ext.stax.XMLSecStartElement;

import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.events.EntityDeclaration;

/**
 * @author $Author: coheigea $
 * @version $Revision: 1354896 $ $Date: 2012-06-28 11:11:05 +0100 (Thu, 28 Jun 2012) $
 */
public class XMLSecEntityReferenceImpl extends XMLSecEventBaseImpl implements XMLSecEntityReference {

    private final String name;
    private final EntityDeclaration entityDeclaration;

    public XMLSecEntityReferenceImpl(String name, EntityDeclaration entityDeclaration, XMLSecStartElement parentXmlSecStartElement) {
        this.name = name;
        this.entityDeclaration = entityDeclaration;
        setParentXMLSecStartElement(parentXmlSecStartElement);
    }

    @Override
    public EntityDeclaration getDeclaration() {
        return entityDeclaration;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public int getEventType() {
        return XMLStreamConstants.ENTITY_REFERENCE;
    }

    @Override
    public boolean isEntityReference() {
        return true;
    }
}

==> xmlsec-2.0.10-sources.jar: org/apache/xml/security/stax/impl/stax/XMLSecEntityReferenceImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.xml.security.stax.impl.stax;

import org.apache.xml.security.stax.ext.stax.XMLSecEntityReference;
import org.apache.xml.security.stax.ext.stax.XMLSecStartElement;

import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.events.EntityDeclaration;
import java.io.IOException;
import java.io.Writer;

/**
 * @author $Author: giger $
 * @version $Revision: 1659901 $ $Date: 2015-02-15 09:11:24 +0000 (Sun, 15 Feb 2015) $
 */
public class XMLSecEntityReferenceImpl extends XMLSecEventBaseImpl implements XMLSecEntityReference {

    private final String name;
    private final EntityDeclaration entityDeclaration;

    public XMLSecEntityReferenceImpl(String name, EntityDeclaration entityDeclaration, XMLSecStartElement parentXmlSecStartElement) {
        this.name = name;
        this.entityDeclaration = entityDeclaration;
        setParentXMLSecStartElement(parentXmlSecStartElement);
    }

    @Override
    public EntityDeclaration getDeclaration() {
        return entityDeclaration;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public int getEventType() {
        return XMLStreamConstants.ENTITY_REFERENCE;
    }

    @Override
    public boolean isEntityReference() {
        return true;
    }

    @Override
    public void writeAsEncodedUnicode(Writer writer) throws XMLStreamException {
        try {
            writer.write('&');
            writer.write(getName());
            writer.write(';');
        } catch (IOException e) {
            throw new XMLStreamException(e);
        }
    }
}
